use dioxus::{document::Stylesheet, prelude::*};

const BUTTON_STYLE: Asset = asset!("/assets/styles/button.scss");

#[derive(Props, Clone, PartialEq)]
pub struct Props {
    #[props(extends = button, extends = GlobalAttributes)]
    pub attributes: Vec<Attribute>,
    #[props(optional, default = None)]
    pub onclick: Option<EventHandler<Event<MouseData>>>,

    pub icon: Option<&'static str>,
    pub link: Option<&'static str>,
    pub primary: Option<bool>,
    pub disabled: Option<bool>,
    pub disable_effects: Option<bool>,

    #[props(optional, default = None)]
    pub children: Element,
}

#[component]
pub fn Button(props: Props) -> Element {
    let item = rsx! {
        div {
            class: {
                let mut classes = vec!["button"];

                if props.disabled.unwrap_or(false) {
                    classes.push("disabled");
                }

                if props.disable_effects.unwrap_or(false) {
                    classes.push("noeffects");
                }

                if props.link.is_some() || props.onclick.is_some() {
                    classes.push("link");
                }

                if props.primary.unwrap_or(false) {
                    classes.push("primary");
                }
                
                classes.join(" ")
            },
            onclick: move |event| {
                // avoid prevent_default
                if props.link.is_some() && !props.disabled.unwrap_or(false) {
                    return;
                }

                if let Some(onclick) = props.onclick {
                    onclick.call(event);
                } else {
                    event.prevent_default();
                }
            },
            ..props.attributes,

            if props.icon.is_some() {
                img { src: props.icon }
            }
            {props.children}
        }
    };

    if let Some(link) = props.link {
        rsx! {
            Stylesheet { href: BUTTON_STYLE }
            a {
                target: "_blank",
                href: link,
                {item}
            }
        }
    } else {
        rsx! {
            Stylesheet { href: BUTTON_STYLE }
            {item}
        }
    }
}
