use std::fmt::{Display, Formatter, Result};

use components::Navbar;
use dioxus::dioxus_core::AttributeValue;
use dioxus::prelude::*;
use serde::{Deserialize, Serialize};
use views::Home;

mod app;
mod components;
mod language;
mod utils;
mod views;

#[derive(Debug, Clone, Routable, PartialEq)]
#[rustfmt::skip]
pub enum Route {
    #[layout(Navbar)]
    #[route("/")]
    Home {}
}

#[derive(PartialEq, Clone, Serialize, Deserialize)]
pub enum Theme {
    Light,
    Dark,
}

impl Theme {
    fn different(&self) -> Self {
        match &self {
            Theme::Light => Theme::Dark,
            Theme::Dark => Theme::Light
        }
    }
}

impl Display for Theme {
    fn fmt(&self, f: &mut Formatter<'_>) -> Result {
        let theme = match &self {
            Theme::Light => "light",
            Theme::Dark => "dark",
        };

        write!(f, "{}", theme)
    }
}

impl IntoAttributeValue for Theme {
    fn into_value(self) -> dioxus_core::AttributeValue {
        AttributeValue::Text(self.to_string())
    }
}

fn main() {
    dioxus::launch(app::App);
}
