use std::sync::{Arc, Mutex};
use dioxus::prelude::*;

mod about;
mod links;
mod tools;

use crate::language::{use_language, LanguageManager};

#[derive(Clone, Props)]
pub(super) struct Props {
    ctx: Arc<Mutex<LanguageManager>>,
}

impl PartialEq for Props {
    fn eq(&self, other: &Self) -> bool {
        let self_ctx = self.ctx.lock().unwrap();
        let other_ctx = other.ctx.lock().unwrap();
        *self_ctx == *other_ctx
    }
}

#[component]
pub fn Home() -> Element {
    let ctx = Arc::new(Mutex::new(use_language()));

    rsx! {
        about::About { ctx: Arc::clone(&ctx) }
        links::Links { ctx: Arc::clone(&ctx) }
        tools::Tools { ctx: Arc::clone(&ctx) }
    }
}
