use dioxus::prelude::*;
use crate::components::Button;

struct Tool {
    name: &'static str,
    icon: &'static str
}

#[component]
pub fn Tools(props: super::Props) -> Element {
    let ctx = props.ctx.lock().unwrap();

    rsx! {
        h2 { id: "tools", {ctx.tr("most_used_languages", None)} }
        div {
            class: "button-stack",
            for tool in MOST_USED_LANGUAGES {
                Button {
                    icon: tool.icon,
                    {ctx.tr(tool.name, None)}
                }
            }
        }

        h2 { {ctx.tr("favourite_tools", None)} }
        div {
            class: "button-stack",
            for tool in TOOLS {
                Button {
                    icon: tool.icon,
                    {ctx.tr(tool.name, None)}
                }
            }
        }
    }
}

static TOOLS: &'static [Tool] = &[
    Tool {
        name: "Docker",
        icon: "/assets/icons/tools/docker.svg"
    },
    Tool {
        name: "NixOS",
        icon: "/assets/icons/tools/nixos.svg"
    },
    Tool {
        name: "React",
        icon: "/assets/icons/tools/react.svg"
    },
    Tool {
        name: "Vim",
        icon: "/assets/icons/tools/vim.svg"
    },
    Tool {
        name: "VSCodium",
        icon: "/assets/icons/tools/vscode.svg"
    },
];

static MOST_USED_LANGUAGES: &'static [Tool] = &[
    Tool {
        name: "CSS3",
        icon: "/assets/icons/languages/css3.svg"
    },
    Tool {
        name: "Go",
        icon: "/assets/icons/languages/golang.svg"
    },
    Tool {
        name: "HTML5",
        icon: "/assets/icons/languages/html5.svg"
    },
    Tool {
        name: "Rust",
        icon: "/assets/icons/languages/rust.svg"
    },
    Tool {
        name: "TypeScript",
        icon: "/assets/icons/languages/typescript.svg"
    }
];
